OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Download" : "Stiahnuť",
    "Copy link" : "Kopírovať odkaz",
    "Click to copy the link to your clipboard" : "Skopírovať odkaz do schránky",
    "Toggle sharing" : "Zapnúť zdieľanie",
    "Delete" : "Zmazať",
    "Rename" : "Premenovať",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "can edit" : "môže upravovať",
    "Close" : "Zatvoriť",
    "Enabled" : "Povolené",
    "Disabled" : "Zakázané",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nepodporované!",
    "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
    "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
    "Address book name" : "Názov adresára kontaktov",
    "Only these special characters are allowed: -_.!?#|()" : "Povolené sú len tieto špeciálne znaky: -_.!?#|()",
    "Address book could not be created." : "Adresár sa nepodarilo sa vytvoriť",
    "The selected image is too big (max 1MB)" : "Vybraný obrázok je príliš veľký (max 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Poškodená karta bola opravená. Skontrolujte prosím údaje a stlačte uložiť pre uplatnenie zmien. ",
    "No contacts in here" : "Nie sú tu žiadne kontakty",
    "Name" : "Názov",
    "Organization" : "Organizácia",
    "Title" : "Názov",
    "Add field …" : "Pridať pole ...",
    "Save changes" : "Uložiť zmeny",
    "Address book" : "Adresár",
    "Loading contacts …" : "Načítavajú sa kontakty ...",
    "Import into" : "Importovať do",
    "Importing..." : "Importujem...",
    "Select your addressbook" : "Vyberte svoj adresár",
    "No search result for {query}" : "Žiadne výsledky vyhľadávania pre {query}",
    "All contacts" : "Všetky kontakty",
    "Post office box" : "Poštová adresa",
    "Postal code" : "PSČ",
    "City" : "Mesto",
    "State or province" : "Štát alebo oblasť",
    "Country" : "Krajina",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "Last name" : "Priezvisko",
    "First name" : "Krstné meno",
    "Additional names" : "Ďalšie mená",
    "Prefix" : "Titul pred menom",
    "Suffix" : "Titul po mene",
    "Importing into" : "Importujem do",
    "New contact" : "Nový kontakt",
    "Not grouped" : "Bez skupiny",
    "Sort by" : "Zoradiť podľa",
    "{addressbook} shared by {owner}" : "{addressbook} sprístupňuje {owner}",
    "Contact not found." : "Kontakt sa nenašiel",
    "You don't have permission to write to this addressbook." : "Pre zápis do tohto adresára nemáte oprávnenia.",
    "Contact could not be created." : "Kontakt nieje možné vytvoriť",
    "No contacts in file. Only vCard files are allowed." : "V súbore nie sú žiadne kontakty. Podporované sú len súbory vCard.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podporované sú iba formáty vCard verzie 4.0 (RFC6350) alebo verzie 3.0 (RFC2426).",
    "Contact could not be moved." : "Kontakt sa nedá presunúť",
    "Contact could not be saved." : "Kontakt nie je možné uložiť",
    "Waiting for the server to be ready…" : "Čaká sa než bude pripravený server...",
    "Importing…" : "Importuje sa...",
    "Display name" : "Zobrazované meno",
    "Nickname" : "Prezývka",
    "Detailed name" : "Podrobné meno",
    "Notes" : "Poznámky",
    "Website" : "Webstránka",
    "Federated Cloud ID" : "Združené Cloud ID",
    "Home" : "Domov",
    "Work" : "Práca",
    "Other" : "Iné",
    "Groups" : "Skupiny",
    "Birthday" : "Narodeniny",
    "Anniversary" : "Výročie",
    "Date of death" : "Dátum smrti",
    "Email" : "Email",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefón",
    "Mobile" : "Mobil",
    "Work mobile" : "Pracovný mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax doma",
    "Fax work" : "Fax v práci",
    "Pager" : "Pager",
    "Voice" : "Odkazová schránka",
    "Car" : "Auto",
    "Work pager" : "Pracovný pager",
    "Social network" : "Sociálna sieť",
    "Relationship" : "Vzťah",
    "Spouse" : "Partner/ka",
    "Child" : "Dieťa",
    "Mother" : "Matka",
    "Father" : "Otec",
    "Parent" : "Rodič",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Príbuzný",
    "Friend" : "Kamarát/ka",
    "Colleague" : "Kolega",
    "Manager" : "Manažér",
    "Assistant" : "Asistent",
    "Gender" : "Pohlavie",
    "Female" : "Žena",
    "Male" : "Muž",
    "Details" : "Podrobnosti",
    "Settings" : "Nastavenia"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
